##
##  spamassassin.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2024 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package version
%define       V_real 4.0.1
%define       V_here 4.0.1
%define       V_sdir 4.0.1

#   package information
Name:         spamassassin
Summary:      Mail Filter Identifying Spam
URL:          http://spamassassin.apache.org/
Vendor:       Justin Mason
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        BASE
Group:        Mail
License:      ASF
Version:      %{V_here}
Release:      20241226

#   package options
%option       with_fsl  yes

#   list of sources
Source0:      http://www.apache.org/dist/spamassassin/source/Mail-SpamAssassin-%{V_real}.tar.gz
Source1:      rc.spamassassin
Source2:      local.cf
Source3:      fsl.spamassassin

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, perl, perl-openpkg >= 5.8.4, make
PreReq:       OpenPKG, openpkg >= 20160101, perl, gnupg
BuildPreReq:  perl-db, perl-crypto, perl-xml, perl-dns, perl-locale, perl-www
PreReq:       perl-db, perl-crypto, perl-xml, perl-dns, perl-locale, perl-www
%if "%{with_fsl}" == "yes"
BuildPreReq:  fsl
PreReq:       fsl
%endif

%description
    SpamAssassin provides you with a way to reduce if not completely
    eliminate Unsolicited Commercial Email (UCE, aka SPAM) from your
    incoming email. It uses a genetic-algorithm evolved scoring system
    to identify messages which look spammy, then adds headers to the
    message so they can be filtered by the user's mail reading software.
    This distribution includes the spamd/spamc components which create a
    server that considerably speeds processing of mail.

%track
    prog spamassassin = {
        version   = %{V_real}
        url       = http://www.apache.org/dist/spamassassin/source/
        regex     = Mail-SpamAssassin-(\d+\.\d+\.\d+)\.tar\.gz
    }

%prep
    %setup -q -n Mail-SpamAssassin-%{V_sdir}

%build
    #   configure package
    %{l_prefix}/bin/perl-openpkg prepare
    export CC="%{l_cc}"
    export CFLAGS="%{l_cflags -O} -Ispamc %{l_cppflags}"
    export LDFLAGS="%{l_ldflags} %{l_fsl_ldflags}"
    export LIBS="%{l_ldflags} %{l_fsl_ldflags} %{l_fsl_libs}"
    %{l_prefix}/bin/perl-openpkg configure \
        -A DESTDIR="$RPM_BUILD_ROOT" \
        -A PREFIX="%{l_prefix}" \
        -A SYSCONFDIR="%{l_prefix}/etc/spamassassin" \
        -A LOCALRULESDIR="%{l_prefix}/etc/spamassassin" \
        -A DATADIR="%{l_prefix}/share/spamassassin" \
        -A PERL_BIN="%{l_prefix}/bin/perl"

    #   build package
    %{l_make} %{l_mflags}

%install

    #   install package
    %{l_make} %{l_mflags} install

    #   install default configuration
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/etc/spamassassin \
        $RPM_BUILD_ROOT%{l_prefix}/etc/spamassassin/sa-update-keys
    %{l_shtool} install -c -m 644 %{l_value -s -a} \
        %{SOURCE local.cf} \
        $RPM_BUILD_ROOT%{l_prefix}/etc/spamassassin/

    #   create directory for PID file
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/var/spamassassin

    #   strip installation
    chmod u+w $RPM_BUILD_ROOT%{l_prefix}/bin/*
    strip $RPM_BUILD_ROOT%{l_prefix}/bin/* >/dev/null 2>&1 || true
    rm -rf $RPM_BUILD_ROOT%{l_prefix}/man/man3

    #   install run-command script
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/etc/rc.d
    %{l_shtool} install -c -m 755 %{l_value -s -a} \
        %{SOURCE rc.spamassassin} $RPM_BUILD_ROOT%{l_prefix}/etc/rc.d/

    #   install OSSP fsl configuration
    %{l_shtool} mkdir -f -p -m 755 $RPM_BUILD_ROOT%{l_prefix}/etc/fsl
    %{l_shtool} install -c -m 644 %{l_value -s -a} \
        %{SOURCE fsl.spamassassin} \
        $RPM_BUILD_ROOT%{l_prefix}/etc/fsl/

    #   determine installation files
    %{l_prefix}/bin/perl-openpkg \
        -F perl-openpkg-files \
        fixate cleanup
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT \
        %{l_files_std} \
        '%config %{l_prefix}/etc/fsl/fsl.spamassassin' \
        '%config %{l_prefix}/etc/spamassassin/*' \
        '%attr(700,%{l_rusr},%{l_rgrp}) %{l_prefix}/etc/spamassassin/sa-update-keys' \
        '%attr(775,%{l_rusr},%{l_rgrp}) %{l_prefix}/var/spamassassin' \
        '%attr(4755,%{l_rusr},%{l_mgrp}) %{l_prefix}/bin/spamc' \
        `cat perl-openpkg-files`

%files -f files

%clean

%post
    if [ $1 -eq 1 ]; then
        #   on initial installation, once run sa-update(1)
        ( echo "Initializing Spamassassin rule database"
        ) | %{l_rpmtool} msg -b -t notice
        su - %{l_rusr} -c "$RPM_INSTALL_PREFIX/bin/sa-update"
    elif [ $1 -eq 2 ]; then
        #   after upgrade, restart service
        eval `%{l_rc} spamassassin status 2>/dev/null`
        [ ".$spamassassin_active" = .yes ] && %{l_rc} spamassassin restart
    fi
    exit 0

%preun
    if [ $1 -eq 0 ]; then
        #   before erase, stop service and remove run-time files
        %{l_rc} spamassassin stop 2>/dev/null
        rm -rf $RPM_INSTALL_PREFIX/var/spamassassin/[0-9]/* >/dev/null 2>&1 || true
        rm -f  $RPM_INSTALL_PREFIX/var/spamassassin/*.pid   >/dev/null 2>&1 || true
        rm -f  $RPM_INSTALL_PREFIX/var/spamassassin/*.log*  >/dev/null 2>&1 || true
    fi
    exit 0

